import axios from './axios.js';
import qs from 'qs';

/**
 * 3.0-产品 服务对应关系
    ems-base-data ->ems-base-application
    ems-admin ->ems-base-application
    mams-rest ->ems-base-application/mams
 */


// 公共组件 接口地址定义
export const componentsNewUrls = {
  // 交通工具
  veniclesUrl: '/ems/ems-base-application/mams/sys/valueset/item/list/VEHICLE',
  batchUrl: '/ems/ems-base-application/mams/sys/valueset/item/batchlist/',
  // 选择城市
  cityUrl: '/ems/ems-base-application/city/findCityListForTrip',
  // 选择成本中心
  costCenterUrl: '/ems-base-application/mdCostCenter/findCostCenterByCondition'
};

// 表单 接口地址定义
export const formUrls = {
  // 初始化表单
  initClaimInfo: "/bill-service/claim/initClaimInfo",
  // 保存
  saveClaimInfo: "/bill-service/claim/saveClaimInfo/",

};

// 返回值结构统一 大类
const fetchData = (url, param, configUrl = '/ems-base-application') => {
  const URI = `${configUrl + url}`;
  return new Promise((resolve) => {
    axios.post(URI, param).then((response) => {
      resolve(response);
    }).catch((error) => {
      const responseData = { dataResult: [], extra: '', msg: (error.response.data.message || '服务异常，请联系管理员'), statusCode: '-1' };
      resolve(responseData);
    });
  });
};

// 获取后台菜单
export const QueryMenu = () => {
  return new Promise((resolve, reject) => {
    axios.post('/ems-base-application/mams/sys/admin/menus').then((response) => {
      if (response.data.statusCode === '0') {
        resolve(response.data.dataResult);
      } else {
        reject(response.data.msg);
      }
    }).catch(error => {
      reject(error);
    })
  });
}

// 获取用户菜单  53改造后获取user信息
export const GetUserMenus = () => {
  return new Promise((resolve) => {
    axios.get('/ems/ems-base-application/tsUserOrg/findCurrentEmployee').then((response) => {
      if (response.data) {
        resolve(response.data);
      }
    });
  });
};


// 根据code获取值集
export const GetValueSetByCode = param => {
  return new Promise((resolve, reject) => {
    axios.get(`/ems-base-application/mams/sys/valueset/item/list/${param.code}`).then((response) => {
      const data = response.data;
      if (data.statusCode === '0') {
        const result = [];
        for (const item of data.dataResult) {
          result.push({ label: item.vsiValue, value: item.vsiKey });
        }
        resolve(result);
      } else {
        reject(data.msg);
      }
    }).catch(err => reject(err));
  });
};

//点击刷新获取核销数据
export const GetwriteOffDate = (params) => {
  return new Promise((resolve) => {
    axios.post(`/bill-service/writeOff/findWriteOff?claimId=${params.claimId}`, params).then((response) => {
      if (response.data) {
        resolve(response.data);
      }
    });
  });
};


// 收款信息查询
export const getActualEmpInfoByEmployeeId = params => {
  return new Promise((resolve) => {
    axios.post(`/bill-service/claim/getActualEmpInfoByEmployeeId?${qs.stringify(params)}`, params).then((response) => {
      const data = response.data;
      if (data.code === "1") {
        resolve(data.obj);
      }
    });
  });
};

// 查询业务小类
export const findSubCategoryByCategoryCode = params => {
  return new Promise((resolve) => {
    axios.post(`/ems/ems-base-application/category/rules/findSubCategoryByCategoryCode/${params.categoryCode}/${params.userLdapId}/${params.businessLineCode}/${params.buCode}`, params).then((response) => {
      const data = response.data;
      resolve(data);
    });
  });
};

// 我的票夹列表查询接口   
export const myWalletList = params => {
  return new Promise((resolve) => {
    axios.post(`/ems/ems-mobile-service/ems-mobile/appHinvoiceInfoPC/findHinvoiceInfoPageListByMobile`, params).then((response) => {
      const data = response.data;
      resolve(data);
    });
  });
};

export const searchValueset = params => {
  return new Promise((resolve) => {
    axios.post(`/ems-base-application/mams/sys/valueset/item/list/INVOICE_MOBILE_TYPE`).then((response) => {
      const data = response.data;
      resolve(data);
    });
  });
};

