import axios from './axios.js';

export const GetValueSetByCode = param => {
  return new Promise((resolve) => {
    axios.get(`/admin/mams-rest/sys/valueset/item/list/${param.code}`).then((response) => {
      resolve(response.data);
    });
  });
};

export const GetRoleDetail = param => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/role/detail?roleId=${param.id}`).then((response) => {
      resolve(response.data.dataResult);
    });
  });
};

export const UpdateRole = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/role/update', param).then((response) => {
      resolve(response.data);
    });
  });
};

export const QueryTemplateList = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/menuTemplate/data', param).then((response) => {
      resolve(response.data.dataResult);
    });
  });
};

export const AddRole = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/role/add', param).then((response) => {
      resolve(response.data);
    });
  });
};

export const GetMenuTree = param => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/menuTemplate/tree?templateId=${param.templateId}`).then((response) => {
      let list = [];
      const checkList = [];
      for (const menu of response.data.dataResult.choosedButton) {
        checkList.push(menu.btnId);
      }
      for (const btn of response.data.dataResult.Buttonlist) {
        for (const b of btn) {
          list.push({
            btnCode: b.btnCode,
            menuId: b.btnId,
            menuName: b.btnName,
            children: b.children || [],
            createTime: b.createTime,
            createUserID: b.createUserID,
            flag: b.flag,
            menuCode: b.menuCode,
            menuModuleId: b.menuId,
            operation: b.operation,
            total: b.total,
            url: b.url
          });
        }
      }
      list = list.concat(response.data.dataResult.menuList);
      resolve({
        data: list,
        checkList
      });
    });
  });
};

export const QueryMenusAndBtns = param => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/button/tree?roleId=${param.roleId}`, param).then((response) => {
      let list = [];
      const checkList = [];
      for (const menu of response.data.dataResult.choosedButton) {
        checkList.push(menu.btnId);
      }
      for (const btn of response.data.dataResult.Buttonlist) {
        for (const b of btn) {
          list.push({
            btnCode: b.btnCode,
            menuId: b.btnId,
            menuName: b.btnName,
            children: b.children || [],
            createTime: b.createTime,
            createUserID: b.createUserID,
            flag: b.flag,
            menuCode: b.menuCode,
            menuModuleId: b.menuId,
            operation: b.operation,
            total: b.total,
            url: b.url
          });
        }
      }
      list = list.concat(response.data.dataResult.menuList);
      resolve({
        data: list,
        checkList
      });
    });
  });
};

// 成员管理 添加成员
export const RoleUserMgAddUserToRole = (param) => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/role/rel/role/add', param).then((response) => {
      resolve(response.data);
    });
  });
};
// 成员管理 删除成员
export const RoleUserMgDeleteUserFromRole = (param) => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/role/rel/role/delete', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 删除角色
export const DeleteRole = (param) => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/role/delete?roleIds=${param.roleIds}`, param).then((response) => {
      resolve({
        success: response.data.statusCode == '0',
        msg: response.data.msg
      });
    });
  });
};

// 权限控制，保存角色选择的功能和资源按钮权限
export const SaveMenusAndBtns = (param) => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/role/assignMenu', param).then((response) => {
      resolve({
        success: response.data.statusCode == '0',
        msg: response.data.msg
      });
    });
  });
};

// 冻结启用角色
export const ToggleLockRole = (param) => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/role/${param.status == 0 ? 'lock' : 'unlock'}`, { roleIds: param.ids }).then((response) => {
      resolve({
        success: response.data.statusCode == '0',
        msg: response.data.msg
      });
    });
  });
};

export const EditUser = (param) => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/account/${param.userId ? 'update' : 'add'}`, param).then((response) => {
      resolve({
        success: response.data.statusCode == '0',
        msg: response.data.msg
      });
    });
  });
};

export const UnlockedUserPwd = (param) => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/account/password/unlock', param).then((response) => {
      resolve({
        success: response.data.statusCode == '0',
        msg: response.data.msg
      });
    });
  });
};

export const QueryUserDetail = (param) => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/account/detail', param).then((response) => {
      resolve(response.data.dataResult);
    });
  });
};

export const QueryRole = (param) => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/role/list/page', param).then((response) => {
      resolve(response.data.dataResult);
    });
  });
};

export const OrgMgQueryOrgListByCompanyId = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/dept/company/direct/sub/list', param).then((response) => {
      resolve(response.data);
    }).catch(() => {
      resolve({
        dataResult: [],
        extra: '',
        msg: '网络异常，请联系管理员',
        statusCode: '-1'
      });
    });
  });
};

export const ToggleLockUser = param => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/account/${param.status == 0 ? 'lock' : 'unlock'}`, { ids: param.ids }).then((response) => {
      resolve({
        success: response.data.statusCode == '0',
        msg: response.data.msg
      });
    });
  });
};

export const GetGroupByOrg = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/org/getOrg', param).then((response) => {
      resolve(response.data.dataResult);
    });
  });
};

export const ImportGroup = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/account/add/batch', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 归属公司维护--保存编辑
export const mdOuSave = param => {
  return new Promise((resolve) => {
    axios.post('/admin/ems-base-data/mdOu/save', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 值集管理---查询具体某个值集
export const getValueSetById = param => {
  return new Promise((resolve) => {
    axios.get(`/admin/mams-rest/sys/valueset/id/${param}`).then((response) => {
      resolve(response.data);
    });
  });
};

// 值集管理---新增值集
export const addValueSet = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/valueset/add', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 值集管理---更新值集
export const updateValueSet = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/valueset/update', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 值集管理---查询值集列表
export const valueSetList = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/valueset/list/page', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 值集管理---删除值集
export const deleteValueSet = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/valueset/delete', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 值集管理---删除值集的值定义
export const deleteValueSetItem = param => {
  return new Promise((resolve) => {
    axios.post('/admin/mams-rest/sys/valueset/item/delete', param).then((response) => {
      resolve(response.data);
    });
  });
};

// 值集管理---值定义下载模板
export const downloadValueSetItemsByVsCode = (id, param) => {
  return new Promise((resolve) => {
    axios.post(`/admin/mams-rest/sys/valueset/item/downloadValueSetItemsByVsCode/${id}`, param).then((response) => {
      resolve(response);
    });
  });
};

// 值集管理---查询具体某个值集
export const getValueSeItemtById = param => {
  return new Promise((resolve) => {
    axios.get(`/admin/mams-rest/sys/valueset/item/id/${param}`).then((response) => {
      resolve(response);
    });
  });
};
