import Vue from 'vue';
import App from './App.vue';
import iView from 'view-design';
import VueRouter from 'vue-router';
import VueI18n from 'vue-i18n';
import './tools/index.js';
// import 'view-design/dist/styles/iview.css'
import './static/css/global.less';
import './myTheme/index.less';
import 'core-js/stable';
import 'regenerator-runtime/runtime';
import store from './vuex';
import config from '../config.json';
import axios from './api/axios.js';
import { routers } from './router';
// import filters from "./filter"; // global filters
import { componentsInstall, Mixin, componentsZh, componentsTw, componentsEn } from 'ems-components-new';
import iviewEn from 'view-design/dist/locale/en-US';
import iviewZh from 'view-design/dist/locale/zh-CN';
import iviewTw from 'view-design/dist/locale/zh-TW';
import { commonZh, commonEn, commonTw } from 'ems-common-lang';
import LocalMixin from '@/mixin/index.js'
import md5 from 'js-md5';
import './assets/icon/iconfont.css'
// Object.keys(filters).forEach(key => {
//   Vue.filter(key, filters[key]);
// });

if (process.env.NODE_ENV === "development") {
  const consoleError = window.console.error
  window.console.error = function (msg) {
    try {
      if (msg && msg.indexOf('[Vue warn]: Invalid prop: type check failed for prop "model". Expected Object, got Array') > -1) {
        return;
      }
    } catch (err) {
    }
    consoleError(msg)
  }

  // console.log("当前运行环境：", process.env.VUE_APP_ENV)
}

// Vue.use(iView) 解决报错问题
Vue.use(iView, {
  i18n: function (path, options) {
    let value = i18n.t(path, options)
    if (value !== null && value !== undefined) {
      return value
    }
    return ''
  }
});

Vue.use(VueI18n);
Vue.use(iView, {
  i18n: function (path, options) {
    const value = i18n.t(path, options);
    if (value !== null && value !== undefined) {
      return value;
    }
    return '';
  }
});
Vue.use(VueRouter);
Vue.use(componentsInstall);
Vue.mixin(LocalMixin);
// 必须要加这个  不然多国语言切换不出效果
Vue.locale = () => { };

Vue.prototype.$config = config[process.env.VUE_APP_ENV];
window.$axios = Vue.prototype.$axios = axios;
Vue.prototype.$md5 = md5



const router = new VueRouter({
  routes: routers
});

router.beforeEach((to, from, next) => {
  iView.LoadingBar.start();
  next();
  router.app.$emit('RouterChangeBefore');
});

router.afterEach(to => {
  if (to && to.meta && to.meta.title) {
    document.title = to.meta.title[1];
  }
  iView.LoadingBar.finish();
});

const i18n = new VueI18n({
  locale: window.localStorage.getItem('lang') || 'zh-CN',
  messages: {
    'zh-CN': Object.assign(iviewZh, commonZh, componentsZh, require('./lang/zh-CN.json')),
    'en-US': Object.assign(iviewEn, commonEn, componentsEn, require('./lang/en-US.json')),
    'zh-TW': Object.assign(iviewTw, commonTw, componentsTw, require('./lang/zh-TW.json'))
  }
});

window.emsConfig = {
  i18n
};

window.$app = new Vue({
  el: '#app',
  router: router,
  store,
  i18n,
  created() {
    if (sessionStorage.crctoken) {
      $axios.defaults.headers.crctoken = sessionStorage.crctoken;
    } else {
      this.$router.push({ path: 'login' });
    }

    this.setMessage();
  },
  methods: {
    setMessage() {
      this.$Message.config({
        duration: 6
      });
      window.$Message = this.$Message
    }
  },
  render: h => h(App)
});
